#include "msp430x16x.h"
#include "bin.h"

#define clock 8                    // 8 MHz = 125ns
#include "delay.h"

#define LCD_OUT P1OUT
#define LCD_DIR P1DIR
#define LCD_VCC BIT0
#define LCD_CLK BIT1
#define LCD_DAT BIT2
#define LCD_DC BIT3
#define LCD_SCE BIT4
#define LCD_RST BIT5
unsigned char temp;

//================= Func Declarations =====================
void LCDINIT (void);
void CPUINIT (void);
void LCDDATA (unsigned char,char);
void LCDON (void);
void LCDRESET (void);
void SPIINIT (void);

//================= CPU Initialization ====================
void CPUINIT (void)
{
// Stop watchdog timer to prevent time out reset
  WDTCTL = WDTPW + WDTHOLD;
  
  __bic_SR_register (OSCOFF);
BCSCTL1 =XTS+XT2OFF;
while(IFG1&=OFIFG)IFG1&=~OFIFG;
BCSCTL2 = SELM0+SELM1;
IE1|=OFIE;
BCSCTL1|=DIVA1;

  LCD_OUT = B8(00110000);
  LCD_DIR = 0xff;
}

//=================== LCD initialization ==================
void LCDINIT (void)
{
  LCDON();
  delay_us (10);
  LCDRESET(); 
  //LCDDATA(0x21,0);           // PowerON, ExtCommandSet
  //LCDDATA(0x09,0);           // Internal HV-gen x3
  //LCDDATA(0xE0,0);           // Set Vop
  ///LCDDATA(0x16,0);          // Bias n=2    //15
  //LCDDATA(0x06,0);           // Temperature coeff 2
  //LCDDATA(0x20,0);           // StandartCommandSet
  //LCDDATA(0x0C,0);           // normal mode, display non-inverted
  LCDDATA(0x21,0);          
  LCDDATA(0x11,0);          
  LCDDATA(0x9C,0);          
  LCDDATA(0x20,0);          
  LCDDATA(0x0C,0);          
  LCDDATA(0x40,0);          
  LCDDATA(0x80,0);                    
  delay_us(10);
}

//================== SPI Initialization ===================
void SPIINIT (void)
{
}

//==================== Turn LCD On ========================
void LCDON (void)
{
 LCD_OUT |= LCD_RST;          // set rst to 1
 delay_ms (1000);
 LCD_OUT |= LCD_VCC;           // set vcc to 1
 delay_ms (1000);

}

//====================== LCD Reset ========================
void LCDRESET (void)
{
 LCD_OUT |= LCD_SCE;         // set sce to 1
 delay_us (100);
 LCD_OUT &=~ LCD_RST;         // set reset to 0
 delay_ms(1000);
 LCD_OUT |= LCD_RST;          // set reset to 1
 delay_ms(1000);
}

//==================== Send Data to LCD ===================
void LCDDATA (unsigned char data, char cd)
{
 unsigned char i=0; 
 LCD_OUT &=~ LCD_SCE;          // set sce to 0
 delay_us (100);
 if (cd == 1) 
          {
           LCD_OUT |= LCD_DC;
          }
          else
          {
           LCD_OUT &= ~LCD_DC; 
          };
            
 delay_us (60);
 for (i=0; i<8; i++)
        {
        temp=(data>>(7-i))&0x01;
          if (temp==0)
          {
          LCD_OUT &=~ LCD_DAT;  
          }
          else
          {
          LCD_OUT |= LCD_DAT;  
          }             
        delay_us(50);
        LCD_OUT |= LCD_CLK;    // set clock 1
        delay_us(50);
        LCD_OUT &=~ LCD_CLK;   // set clock 0
        delay_us(50);       
        }
  LCD_OUT |= LCD_SCE;          // set sce to 1
  delay_us(10);
}

//====================== Sending TEST Data to LCD
void LCDTEST(void)
{ unsigned char i;
  for ( i=0; i<(51); i++ )
  {
    LCDDATA(B8(01010101), 1);
    delay_us (100);
  }
}


void main( void )
{ 
  CPUINIT ();
  LCDINIT ();
  for(;;)
  {
  LCDTEST ();
  }
